"""Generate a QR code to make it easy for other people to connect to the wifi
network.
"""

import qrcode
import getpass

def wifi_code(ssid, hidden, authentication_type, password=None):
    """Generate a wifi code for the given parameters
    
    :ssid str: SSID
    :hidden bool: Specify if the network is hidden
    :authentication_type str: Specify the authentication type. Supported types: WPA, WEP, nopass
    :password Optional[str]: Password. Not required if authentication type is nopass
    
    :return: The wifi code for the given parameters
    :rtype: str
    """
    hidden = 'true' if hidden else 'false'
    if authentication_type in ('WPA', 'WEP'):
        if password is None:
            raise TypeError('For WPA and WEP, password should not be None.')
        return 'WIFI:T:{type};S:{ssid};P:{password};H:{hidden};;'.format(
            type=authentication_type, ssid=ssid, password=password, hidden=hidden
        )
    elif authentication_type == 'nopass':
        if password is not None:
            raise TypeError('For nopass, password should be None.')
        return 'WIFI:T:nopass;S:{ssid};H:{hidden};;'.format(
            ssid=ssid, hidden=hidden
        )
    raise ValueError('Unknown authentication_type: {!r}'.format(authentication_type))

def wifi_qrcode(ssid, hidden, authentication_type, password=None, **kwargs):
    """Generate Wifi QR code for given parameters
    :ssid str: SSID
    :hidden bool: Specify if the network is hidden
    :authentication_type str: Specify the authentication type. Supported types: WPA, WEP, nopass
    :password Optional[str]: Password. Not required if authentication type is nopass
    :kwargs: Optional keyword arguments to use with `qrcode.make`. See the arguments for `qrcode.QRCode`.
    :return: An image of the qrcode for the given parameters
    :rtype: PIL.Image.Image
    """

    return qrcode.make(wifi_code(ssid, hidden, authentication_type, password), **kwargs).get_image()


def qrcrt():
    while True:
        ssid = input("SSID: ")
        if ssid == "":
            print("Input is not valid!")
        else:
            break

    while True:
        hidden = input("Is the network hidden (default is false): ").lower()
        if hidden in ['yes', 'y', 'true', 't']:
            hidden = True
            break
        elif hidden in ['', 'no', 'n', 'false', 'f']:
            hidden = False
            break
        else:
            print("Input is not valid!")
    
    while True:
        print("Authentication types: WPA/WPA2, WEP, nopass")
        authentication_type = input("Authentication type (default is "
                                    "WPA/WPA2): ").lower()
        if authentication_type in ['', 'wpa2', 'wpa', 'wpa/wpa2', 'wpa2/wpa']:
            authentication_type = 'WPA'
            break
        elif authentication_type == 'WEP' or authentication_type == 'nopass':
            break
        else:
            print("Input is not valid!")
    
    while True:
        if authentication_type == 'nopass':
            password = None
            break    
        password = getpass.getpass("Password: ")
        if password == "":
            print("Input not valid!")
        else:
            break
    qrcode = wifi_qrcode(ssid, hidden, authentication_type, password)
    qrcode.save('/tmp/key.png')
    print("The qr code has been created.")


import qrcode
import os
import re
def ssidgen():
    os.system("ls -1 /etc/NetworkManager/system-connections/ > /tmp/wifilist.txt")
    with open("/tmp/wifilist.txt", 'r') as file_handle:
    # read file content into list
        lines = file_handle.readlines()
# print list content
    for x in range(len (lines)):
        linex=lines[x]
        print(f"({x}) >>> {linex[0:-14]}")
    # print()
    inputnum = int(input("Enter Number of Name:"))
    print('\n')
    catt = lines[inputnum].rstrip("\n")
    # print(catt)
    os.system(f" sudo cat /etc/NetworkManager/system-connections/'{str(catt)}' > /tmp/wifi.txt",)
    file_handle.close()
    f = open("/tmp/wifi.txt",'r')
    with f as open_file:
        data = open_file.read()
        reg = []
        reg = re.findall(r'ssid=.*',data)
        for i in reg:
            #print (i)
            return i
        return ssidgen()
def pskgen():
    # os.system("ls -l /etc/NetworkManager/system-connections/")
    # catt = input("Enter wifiName:")
    # os.system(f" sudo cat /etc/NetworkManager/system-connections/{catt} > /tmp/wifi.txt",)
    f = open("/tmp/wifi.txt",'r')
    with f as open_file:
        data = open_file.read()
        reg = []
        reg = re.findall(r'psk=.*',data)
        for i in reg:
            #print (i)
            return i
        return pskgen()
def authtype():
    # os.system("ls -l /etc/NetworkManager/system-connections/")
    # catt = input("Enter wifiName:")
    # os.system(f" sudo cat /etc/NetworkManager/system-connections/{catt} > /tmp/wifi.txt",)
    f = open("/tmp/wifi.txt",'r')
    with f as open_file:
        data = open_file.read()
        reg = []
        reg = re.findall(r'key-mgmt=.*',data)
        for i in reg:
            #print (i)
            return i
        return authtype()



import setuptools 
setuptools.setup (
    name = "wifiqr",
    version="1.2.1",
    author="Pyae Phyo Hein",
    author_email="pyaephyohein.info.3326@gmail.com",
    descripton="Wifi Qr creater and generator for linux",
    packages=["wifiqr"],
    entry_points = {
        'console_scripts' : ['wifiqr=wifiqr.wifiqr:wifiqr']
    },
    install_requires=[
        'qrcode'
    ]
    )



#author = Pyae Phyo Hein
#idea from https://github.com/kokoye2007/wifi-qr
#MIT License
#https://github.com/lakhanmankani/wifi_qrcode_generator (Some of code copy from this repo)
#31.12.2019
import sys
import os
from . import wifi_qrcode_created
from . import wifi_qrcode_gener
def wifiqr():
    xdgop = "xdg-open '/tmp/key.png'"
    print('1) Create Wifi QR Code')
    print('2) Generate Wifi QR Code')
    print('3) Scan QR Code')
    chmanu = input('Select Option ')
    if chmanu == "1":
        wifi_qrcode_created.qrcrt()
        os.system(xdgop)
    elif chmanu == "2":
        ssidraw = wifi_qrcode_gener.ssidgen()
        pskraw = wifi_qrcode_gener.pskgen()
        ssid = ssidraw[5:]
        hidden = False
        autheraw = wifi_qrcode_gener.authtype().upper()
        authentication_type = autheraw[9:12]
        password = pskraw[4:]
        code = wifi_qrcode_created.wifi_qrcode(ssid, hidden, authentication_type, password)
        code.save('/tmp/key.png')
        os.system(xdgop)
        print("The qr code has been generated.")
    elif chmanu == "3":
        print("qrscanner Under processing...")
    else:
        print('\n\n!!!!!!!!!!!!!!!Something Wrong!!!!!!!!!!!!!!!\n\n')